# iQ WorkBook - книга проекта

Добро пожаловать в книгу проекта «iQWorkBook» - самой удобной системы накопления знаний!

Подробней узнать, что это за проект и ознакомиться со всеми его возможностями можно на страницах этого руководства.

Основные места которые вам могут быть интересны:

- [Репозиторий проекта](https://gitflic.ru/project/iqstudio/iqworkbook) — для желающих присоединиться к разработке
- [Книга проекта](https://iqworkbook.gitflic.space/) — здесь собрана справочная информация для пользователей

Это проект с открытым исходным кодом, придерживающийся философии свободного ПО, который вы можете бесплатно использовать в рамках лицензии. Реализовано группой энтузиастов [iQStudio](https://gitflic.ru/team/iqstudio).

*с благодарностью к участникам, пользователям и компаниям поддержавшим это начинание*

Биробиджан-Хабаровск-Благовещенск, 2018-2022 г.г.
 
